{
  config,
  home-manager,
  flake,
  lib,
  pkgs,
  ...
}:
with lib; let
  psCfg = config.pub-solar;
  xdg = config.home-manager.users."${psCfg.user.name}".xdg;
  tritonshell = flake.inputs.tritonshell;
in {
  imports = [
    ./session-variables.nix
    ./concepts-and-training.nix
    ./mnx.nix
  ];

  config = {
    # TODO change in alacritty config directly
    #pub-solar.graphical.alacritty.settings.font.size = 12;
    #pub-solar.graphical.alacritty.settings.key_bindings = [
    #  {
    #    key = "V";
    #    mods = "Control|Super";
    #    action = "Paste";
    #  }
    #  {
    #    key = "C";
    #    mods = "Control|Super";
    #    action = "Copy";
    #  }
    #];
    #services.kbfs.enable = true;
    #services.keybase.enable = true;

    users.users."${psCfg.user.name}" = {
      extraGroups = ["dialout"];
    };
    home-manager.users.${psCfg.user.name} = {
      xdg.configFile."git/config".text = import ./.config/git/config.nix {
        inherit config;
        inherit pkgs;
      };
      xdg.configFile."git/config_greenbaum.cloud".text = import ./.config/git/config_greenbaum.cloud.nix {
        inherit config;
        inherit pkgs;
      };
      xdg.configFile."git/config_mnx".text = import ./.config/git/config_mnx.nix {
        inherit config;
        inherit pkgs;
      };
      xdg.configFile."git/config_git.b12f.io".text = import ./.config/git/config_git.b12f.io.nix {
        inherit config;
        inherit pkgs;
      };
      xdg.configFile."tmate/tmate.conf".text = import ./.config/tmate/config.nix {
        inherit config;
        inherit pkgs;
      };
      xdg.configFile."watson/config".text = import ./.config/watson/config.nix {
        inherit config;
        inherit pkgs;
      };

      home.packages = with pkgs; [
        AusweisApp2
        consul
        drone-docker-runner
        gpu-switch
        ifmetric
        ipmitool
        #keybase-gui
        nomad_1_4
        thunderbird
        vault
        veracrypt
        waypoint
        age-plugin-yubikey
        #cockroach-bin
        obs-studio
        wlvncc
      ];
      programs.bash.initExtra = ''
        source ${config.age.secrets.environment-secrets.path}
        source ${flake.inputs.tritonshell.packages.${pkgs.system}.triton-utils}/bin/ttp.sh

        complete -C ${pkgs.consul}/bin/consul consul
        complete -C ${pkgs.nomad_1_4}/bin/nomad nomad
        complete -C ${pkgs.vault}/bin/vault vault
        complete -C ${flake.inputs.nixos-22-05.legacyPackages.${pkgs.system}.terraform}/bin/terraform terraform
        complete -C ${pkgs.waypoint}/bin/waypoint waypoint
        complete -C ${pkgs.opentofu}/bin/tofu tofu
      '';

      # xdg.configFile."wallpaper.jpg".source = ./assets/wallpaper.jpg;
    };

    #services.mopidy.configuration = mkIf config.pub-solar.audio.enable (builtins.readFile ../../secrets/mopidy.conf);
  };
}
